@@ -49,6 +49,8 @@ def test_path():
         url /= 0.1
     with raises(AttributeError):
         url /= True
+    with raises(AttributeError):
+        url.add_path(["a", "b", 1, 2])
 
     assert url.get == "https://example.com/test/more/paths/added"
 
@@ -75,6 +77,10 @@ def test_path():
     url = BuildURL("https://example.com/folder/")
     assert url.get == "https://example.com/folder/"
 
+    url = BuildURL("https://example.com")
+    url.add_path("one", "two", ["three", "four", "five", "six"], "seven//eight")
+    assert url.get == "https://example.com/one/two/three/four/five/six/seven/eight"
+
 
 def test_query():
     url = BuildURL("https://example.com")
@@ -108,6 +114,35 @@ def test_query():
     url.query = None
     assert url.get == "https://example.com"
 
+    url = BuildURL("https://example.com")
+    url.add_query("a=b&c=d", {"e": "f", "g": "h"}, i="j", k="l")
+    assert url.get == "https://example.com?a=b&c=d&e=f&g=h&i=j&k=l"
+
+
+def test_trailing_slash():
+    url = BuildURL("https://example.com/")
+    assert url.get == "https://example.com/"
+
+    url = BuildURL("https://example.com/test", force_trailing_slash=True)
+    assert url.get == "https://example.com/test/"
+
+    url = BuildURL("https://example.com")
+    url /= "test/"
+    assert url.get == "https://example.com/test/"
+
+    url = BuildURL("https://example.com")
+    url.add_path("test").set_force_trailing_slash().add_query(a="b")
+    assert url.get == "https://example.com/test/?a=b"
+    url.set_force_trailing_slash(False)
+    assert url.get == "https://example.com/test?a=b"
+    url.trailing_slash = True
+    assert url.get == "https://example.com/test/?a=b"
+    url /= "path"
+    assert url.get == "https://example.com/test/path?a=b"
+    url.force_trailing_slash = True
+    url /= "more"
+    assert url.get == "https://example.com/test/path/more/?a=b"
+
 
 def test_copy():
     url = BuildURL("https://example.com")
@@ -120,8 +155,29 @@ def test_copy():
 
 def test_repr():
     url = BuildURL("https://example.com")
-    assert repr(url) == "BuildURL(base='https://example.com')"
+    assert (
+        repr(url) == "BuildURL(base='https://example.com', force_trailing_slash=False)"
+    )
     url /= "repr"
-    assert repr(url) == "BuildURL(base='https://example.com/repr')"
+    assert (
+        repr(url)
+        == "BuildURL(base='https://example.com/repr', force_trailing_slash=False)"
+    )
     url += {"testing": "it"}
-    assert repr(url) == "BuildURL(base='https://example.com/repr?testing=it')"
+    assert (
+        repr(url)
+        == "BuildURL(base='https://example.com/repr?testing=it', force_trailing_slash=False)"
+    )
+
+    url = BuildURL("https://example.com", force_trailing_slash=True)
+    assert (
+        repr(url) == "BuildURL(base='https://example.com/', force_trailing_slash=True)"
+    )
+
+
+def test_chaining():
+    url = BuildURL("https://example.com")
+    url.add_path("one").add_path("two")
+    assert url.get == "https://example.com/one/two"
+    url.add_query({"test": "more"}).add_path("three").add_query("testing=alot")
+    assert url.get == "https://example.com/one/two/three?test=more&testing=alot"
